'use strict';

exports.__esModule = true;

var _popperUtils = require('popper.js/dist/popper-utils');

var _popperUtils2 = _interopRequireDefault(_popperUtils);

var _popper = require('popper.js');

var _popper2 = _interopRequireDefault(_popper);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @author: laurent blanes <laurent.blanes@gmail.com>
 */
var BASE_CLASS = 'vue-tooltip';

/**
 * usage:
 *
 * // basic usage:
 * <div v-tooltip="'my content'">
 * or
 * <div v-tooltip="{content: 'my content'}">
 *
 * // change position of tooltip
 * // options: bottom (default) | top | left | right
 * <div v-tooltip.top="{content: 'my content'}">
 *
 * // add custom class
 * <div v-tooltip="{class: 'custom-class', content: 'my content'}">
 *
 * // toggle visibility
 * <div v-tooltip="{visible: false, content: 'my content'}">
 */
exports.default = {
    name: 'tooltip',
    config: {},
    install: function install(Vue) {
        Vue.directive('tooltip', {
            bind: function bind(el, binding, vnode) {
                var $popper = null;
                var placement = 'bottom';

                if (binding.modifiers.left) {
                    placement = 'left';
                } else if (binding.modifiers.right) {
                    placement = 'right';
                } else if (binding.modifiers.top) {
                    placement = 'top';
                } else if (binding.modifiers.bottom) {
                    placement = 'bottom';
                }

                // wrapper
                $popper = document.createElement('div');
                $popper.setAttribute('class', BASE_CLASS);
                _popperUtils2.default.setStyles($popper, { visibility: 'hidden' });

                // make arrow
                var $arrow = document.createElement('div');
                $arrow.setAttribute('x-arrow', '');
                $popper.appendChild($arrow);

                // make content container
                var $content = document.createElement('div');
                $content.setAttribute('class', 'vue-tooltip-content');
                $popper.appendChild($content);

                document.querySelector('body').appendChild($popper);

                var options = Object.assign({}, binding.value, {
                    placement: placement,
                    onCreate: function onCreate(e) {
                        setProperties(el, binding);
                        setAttributes($popper, $content, el);
                    },
                    onUpdate: function onUpdate(e) {
                        setAttributes($popper, $content, el);
                    }
                });
                el.popper = new _popper2.default(el, $popper, options);
            },
            inserted: function inserted(el, binding, vnode, oldVnode) {
                el.addEventListener('mouseover', onMouseOver);
                el.addEventListener('mouseout', onMouseOut);
                el.addEventListener('mouseleave', onMouseOut);
            },
            componentUpdated: function componentUpdated(el, binding, vnode, oldVnode) {
                setProperties(el, binding);
            },
            unbind: function unbind(el, binding, vnode, oldVnode) {
                el.removeEventListener('mouseover', onMouseOver);
                el.removeEventListener('mouseout', onMouseOut);
                el.removeEventListener('mouseleave', onMouseOut);
                document.querySelector('body').removeChild(el.popper.popper);
            }
        });
    }
};


function setProperties(el, binding) {
    if (typeof binding.value === 'string') {
        el.popper._class = '';
        el.popper._content = binding.value;
        el.popper._visible = true;
    } else {
        el.popper._class = binding.value.class || '';
        el.popper._content = binding.value.content;
        el.popper._visible = binding.value.visible !== false;
    }
}

function setAttributes($popper, $content, el) {
    $content.innerHTML = el.popper._content;
    _popperUtils2.default.setStyles(el.popper.popper, {
        display: el.popper._visible ? 'inline-block' : 'none'
    });
    var classes = BASE_CLASS + ' ' + el.popper._class;
    $popper.setAttribute('class', classes.trim());
}

function onMouseOver(e) {
    var el = e.currentTarget;
    _popperUtils2.default.setStyles(el.popper.popper, { visibility: 'visible' });
    el.popper.update();
}

function onMouseOut(e) {
    var el = e.currentTarget;
    _popperUtils2.default.setStyles(el.popper.popper, { visibility: 'hidden' });
}
module.exports = exports['default'];